@@ -3,10 +3,31 @@ from typing import Union
 
 import pytest
 
+from t_support import cov, cov_counter
 from funk_py.modularity.basic_structures import pass_
 from funk_py.sorting.pieces import convert_tuplish_dict
 
 
+# The following manages whether the generated coverage instance from t_support should report. This
+# method of coverage is used so that coverage can be turned off to not interfere in timed tests.
+@pytest.fixture(scope='session', autouse=True)
+def c():
+    cov_counter.value += 1
+
+    yield cov
+
+    cov_counter.value -= 1
+
+    # We don't want to report till all test modules are completed...
+    if not cov_counter.value:
+        cov.stop()
+        cov.save()
+        cov.html_report()
+
+
+NEWLINE = '\n'
+
+
 @dataclass
 class TuplishDictDef:
     data: Union[dict, list]
